/* XPM */
/* $XConsortium: Dtbitmp.t.pm /main/3 1995/07/18 16:31:47 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/
static char * Dtbitmp_t_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"16 16 4 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s none	m none	c none",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o	s iconColor1	m black	c black",
/* pixels */
"             ...",
"   X  X  Xooo...",
"   X  X  Xooo...",
" XXXXXXXXXXXo...",
" ooX  X  X  o...",
" ooX  X  X  o...",
" XXXXXXXXXXXo...",
" ooXooX  X  o...",
" ooXooX  X  o...",
" XXXXXXXXXXXo...",
" ooXooXooX  o...",
" ooXooXooX  o...",
" XXXXXXXXXXXo...",
" ooXooXooXooo...",
" ooXooXooXooo...",
" oooooooooooo..."};
