/* XPM */
/* $XConsortium: Fpupon.l.pm /main/2 1996/07/23 12:25:13 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * Fupon [] = {
/* width height ncolors cpp [x_hot y_hot] */
"48 10 4 1 0 0",
/* colors */
" 	s background	m black	c #969696969696",
".	s bottomShadowColor	m black	c #646464646464",
"X	s topShadowColor	m white	c #c8c8c8c8c8c8",
"o	s iconColor6	m white	c yellow",
/* pixels */
"                                                ",
"                                                ",
"                       .X                       ",
"                      .ooX                      ",
"                     .ooooX                     ",
"                    .ooooooX                    ",
"                   .ooooooooX                   ",
"                  .XXXXXXXXXXX                  ",
"                                                ",
"                                                "};
