/* XPM */
/* $XConsortium: color.pm /main/5 1996/07/23 14:07:07 drk $ */
static char * ColorOL [] = {
/* width height ncolors cpp [x_hot y_hot] */
"64 37 13 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s bottomShadowColor	m black	c #646464646464",
"X	s iconGray2	m white	c #c8c8c8c8c8c8",
"o	s iconGray1	m white	c #e1e1e1e1e1e1",
"O	s iconGray3	m white	c #afafafafafaf",
"+	s iconGray5	m black	c #7d7d7d7d7d7d",
"@	s iconColor3	m black	c red",
"#	s iconColor6	m white	c yellow",
"$	s iconGray8	m black	c #323232323232",
"%	s topShadowColor	m white	c #c8c8c8c8c8c8",
"&	s iconColor4	m white	c green",
"*	s iconColor5	m black	c blue",
"=	s iconColor8	m black	c magenta",
/* pixels */
"                                                                ",
"                                                                ",
"                                                                ",
"                          ............                          ",
"                      .....XXoXoooooo....                       ",
"                    ...XoXooXoXoXXoXooXo...                     ",
"                  ...XoXoXOOOOOOOOOOOoXooo...                   ",
"                ...XXooOOOOOOOOOOOOOOOOOooXo..                  ",
"               ..oXoXOOOOOOOOOOOO++++++OOOOoX..                 ",
"              ..ooOOOOOOO@OOOOOO+######+OOOOXXX.                ",
"             ..oXOOOOO@@@@@@@OO+########$OOOOO+%                ",
"            ..XoOOOO@@@@@@@@@$+#######$$$OOOO+$%                ",
"           ..ooOOOO@@@@@@@@@$$+######$$OOOOO+$%                 ",
"          ..ooOOOOOOO@@@@@@$$OOO$##$$$OOOO+$$%                  ",
"          .XoOOOOOOOOO@@@@@$OOOO$$$$OOOO++$$%                   ",
"         ..oOOOOOOOOOOO$$$$$OOOOOOOOOOO$$$%%                    ",
"         .XoOOOOO+++OOOOOOOOO$$$$$+OOO+$%%                      ",
"         .oOOOO++o&o+OOOOOOO$$    oOO$$%    ....                ",
"         .oOOO+o&o&o&+OOOOOO$     oOO+$%  ..ooX%                ",
"         .oOO+&o&o&o&o$OOOOO$     oOO+o...XoXOO%                ",
"         .oOO+&o&o&o&$$OOOOO+oooooOOOOXooooOOO$%                ",
"         .oOOO+o&o&o$$OOOOOOOOOOOOOO***OOOOOO+%                 ",
"         .XXOOO$$$$$$OOOOOO=OOOOOOO*****$OOO+$%                 ",
"          .oOOOOOOOOOO========OOOO******$OOO$%                  ",
"          .XXOOOOOOOOO=========OO******$OOO+$%                  ",
"           .XXOOOOOOOOOO=======$O*****$OOO$$%                   ",
"             X$$+OOOOOOO$$==$$$$OO$$$OOO$$$%%                   ",
"              %%$$++OOOOOO$$$OOOOOOOOOO$$+%%                    ",
"               %%%$$$+OOOOOOOOOOOOOO$$$++%%                     ",
"                 %%%%$$$+++++++++$+$$++%%%                      ",
"                    %%%%$$$$$$$$+$+++%%%                        ",
"                       %%%%%%%%%%%%%%%                          ",
"                                                                ",
"                                                                ",
"                                                                ",
"                                                                ",
"                                                                "};
